@@ -1,3 +1,5 @@
+from importlib.metadata import version as v
+
 import typer
 from dotenv import load_dotenv
 
@@ -15,3 +17,12 @@ app.add_typer(lambdas.app, name='lambda')
 app.add_typer(layers.app, name='layers')
 app.add_typer(local.app, name='api')
 app.add_typer(project.app, name='project')
+
+
+@app.callback(invoke_without_command=True)
+def callback_version(version: bool = False):
+    """
+    Prints the version of the CLI.
+    """
+    if version:
+        typer.echo(f'version: {v("aoricaan-cli")}')
