@@ -17,7 +17,8 @@ app = typer.Typer()
 
 @app.command('synth')
 def build_project(set_outputs: bool = typer.Option(False, help="Set outputs in lambdas template."),
-                  use_export: bool = typer.Option(False, help="Set export name for outputs in lambdas template.")):
+                  use_export: bool = typer.Option(False, help="Set export name for outputs in lambdas template."),
+                  add_export_prefix: str = typer.Option(False, help="Set export prefix name for outputs in lambdas template")):
     """
     Build the files for deploy the project in aws.
     """
@@ -30,7 +31,7 @@ def build_project(set_outputs: bool = typer.Option(False, help="Set outputs in l
 
     build_all_lambdas(lambdas_path=lambdas_path, path_cfn_template=template_paths,
                       path_swagger_template=api_paths, bucket=os.environ.get('artifact_bucket'),
-                      set_outputs=set_outputs, use_export=use_export)
+                      set_outputs=set_outputs, use_export=use_export, add_export_prefix=add_export_prefix)
     update_deploy_id_resource_api_gateway(paths_template=template_paths)
     build_layers(layers_path=layers_path)
 
