@@ -8,6 +8,8 @@ import typer
 
 from aoricaan_cli.src.utils.data_types import Verbs
 from aoricaan_cli.src.utils.debugger import Debug
+from aoricaan_cli.src.utils.globals import load_config
+from aoricaan_cli.src.utils.str_parser import snake_case_or_kebab_case_to_pascal_case
 
 utils_templates_path = Path('utils/templates')
 path_lambda_configuration = utils_templates_path.joinpath('lambda.json')
@@ -16,11 +18,13 @@ path_lambda_swagger = utils_templates_path.joinpath('api_verbs.json')
 
 configuration_name = 'configuration.json'
 
+FN_SUB = "Fn::Sub"
+
 
 def create_lambda_configuration(*, new_lambda_folder: Path, handler: str, name: str):
     cfn_lambda = json.loads(path_lambda_configuration.read_text())
     _cfn_lambda = cfn_lambda
-    _cfn_lambda['Properties']['FunctionName']["Fn::Sub"] = "${Environment}-" + name
+    _cfn_lambda['Properties']['FunctionName'][FN_SUB] = "${Environment}-" + name
     _cfn_lambda['Properties']['Code'] = str(new_lambda_folder).replace(os.sep, "/")
     _cfn_lambda['Properties']['Handler'] = handler
     return _cfn_lambda
@@ -42,7 +46,6 @@ def create_swagger_configuration(*, lambda_name: str, endpoint: str, verb: str,
 def create_lambda_files(new_lambda_folder: Path):
     new_lambda_folder.joinpath('__init__.py').write_text("", encoding='utf-8')
     new_lambda_folder.joinpath('test_lambda_function.py').write_text("", encoding='utf-8')
-    # TODO: modificar el nombre de la funcion respecto al handler espesificado.
     new_lambda_folder.joinpath('lambda_function.py').write_text(path_lambda_template.read_text(),
                                                                 encoding='utf-8')
 
@@ -73,6 +76,8 @@ def get_all_lambdas_folder_name(path: Path):
 def load_all_endpoints(path: Path):
     all_lambdas = get_all_lambdas_folder_name(path)
     for name_path in all_lambdas:
+        if not path.joinpath(name_path).joinpath(configuration_name).exists():
+            continue
         config = json.loads(path.joinpath(name_path).joinpath(configuration_name).read_text())
         swagger = config['swagger']
         endpoint = list(swagger)[0] if swagger else ''
@@ -123,9 +128,15 @@ def copytree(src, dst, symlinks=False, ignore=None):
 
 
 def rename_lambda(*, old_path, new_path):
-    new_path.mkdir()
-    copytree(old_path, new_path)
-    shutil.rmtree(old_path)
+    if not new_path.joinpath(configuration_name).exists():
+        return None
+    configuration = new_path.joinpath(configuration_name).read_text()
+    configuration = configuration.replace(old_path.name, new_path.name)
+    if json.loads(configuration).get('swagger'):
+        old_reference_name = snake_case_or_kebab_case_to_pascal_case(old_path.name)
+        new_reference_name = snake_case_or_kebab_case_to_pascal_case(new_path.name)
+        configuration = configuration.replace(old_reference_name, new_reference_name)
+    new_path.joinpath(configuration_name).write_text(configuration)
 
 
 # ---------------------------------------------------------------------------------------------------------------------
@@ -153,7 +164,8 @@ def parse_lambda_code(handler: str):
     :param handler:
     :return:
     """
-    code_lambda = path_lambda_template.read_text()
+    _path_lambda_template = Path(load_config().templates.code.lambda_template)
+    code_lambda = _path_lambda_template.read_text()
     return code_lambda.format(handler=handler)
 
 
@@ -165,8 +177,9 @@ def parse_lambda_cfn_configuration(*, handler: str, name: str, path: Path):
     :param path:
     :return:
     """
-    cfn_lambda = json.loads(path_lambda_configuration.read_text())
-    cfn_lambda['Properties']['FunctionName']["Fn::Sub"] = cfn_lambda['Properties']['FunctionName']["Fn::Sub"].replace(
+    _path_lambda_cfn = Path(load_config().templates.code.lambda_cfn_template)
+    cfn_lambda = json.loads(_path_lambda_cfn.read_text())
+    cfn_lambda['Properties']['FunctionName'][FN_SUB] = cfn_lambda['Properties']['FunctionName'][FN_SUB].replace(
         "{{name}}", name)
     cfn_lambda['Properties']['Code'] = cfn_lambda['Properties']['Code'].replace("{{code}}",
                                                                                 path.__str__().replace(os.sep, '/'))
@@ -199,7 +212,7 @@ def validate_if_exist_verb_in_endpoint(verb: Verbs, endpoint: str):
     :param endpoint:
     :return:
     """
-    from aoricaan_cli.src.lambdas import work_path
+    work_path = Path(load_config().project.folders.lambdas)
     endpoints = {}
     for lmd in os.listdir(work_path):
         if not work_path.joinpath(lmd).is_dir() or (not work_path.joinpath(lmd).joinpath(configuration_name).exists()):
@@ -222,17 +235,19 @@ def add_new_layer_definition(name: str):
     Add the cfn definition of a new layer inside the project.
     :return:
     """
-    path = Path('projectTemplate.json')
+    global_params = load_config()
+    path = Path(global_params.templates.deploy.project_template)
     cfn_definition = json.loads(path.read_text())
     cfn_definition['Resources'][f'Layer{name.capitalize()}'] = {
         "Type": "AWS::Lambda::LayerVersion",
         "Properties": {
             "CompatibleRuntimes": [
+                "python3.8",
                 "python3.9"
             ],
-            "Content": f"src/layers/{name}",
+            "Content": f"../{global_params.project.folders.layers}/{name}",
             "LayerName": {
-                "Fn::Sub": "${Environment}-" + name
+                FN_SUB: "${Environment}-" + name
             }
         }
     }
@@ -245,7 +260,8 @@ def delete_layer_definition(name: str):
     :param name:
     :return:
     """
-    path = Path('projectTemplate.json')
+    global_params = load_config()
+    path = Path(global_params.templates.deploy.project_template)
     cfn_definition = json.loads(path.read_text())
     try:
         del cfn_definition['Resources'][f'Layer{name.capitalize()}']
@@ -262,7 +278,8 @@ def rename_layer_definition(*, src: str, dst: str):
     :param dst:
     :return:
     """
-    path = Path('projectTemplate.json')
+    global_params = load_config()
+    path = Path(global_params.templates.deploy.project_template)
     cfn_definition = json.loads(path.read_text())
     try:
         cfn_definition['Resources'].pop(f'Layer{src.capitalize()}')
